@@ -202,7 +202,7 @@ void HelpScreen()
   printf("Usage: lcdproc [-d device] [-c contrast] [modelist]\n");
   printf("\tOptions in []'s are optional.\n");
   printf("\t-l driver is the output driver to use:\n");
-  printf("\t\tMtxOrb, curses, text, debug\n");
+  printf("\t\tMtxOrb, PICanLCD, HD44780, curses, text, debug\n");
   printf("\t-d device is what the lcd display is hooked to. (/dev/cua0?)\n");
   printf("\t-c contrast sets the screen contrast (0 - 255)\n");
   printf("\tmodelist is \"mode [mode mode ...]\"\n");
