@@ -181,39 +181,45 @@ static int get_fs(mounts fs[])
 
   // Get rid of old, unmounted filesystems...
   memset(fs, 0, sizeof(mounts)*256);
+
+	printf("Done reading filesystems: %i read.\n", x);
   
   while (x < 256)
   {
-    if(fgets(line, 256, mtab_fd) == NULL)
-      {
+     printf("...%i\n", x+1);
+     if(fgets(line, 256, mtab_fd) == NULL)
+     {
+	printf("Done reading filesystems: %i read.\n", x);
 	fclose(mtab_fd);
 	return x;
-      }
+     }
     
-    sscanf(line, "%s %s %s", fs[x].dev, fs[x].mpoint, fs[x].type);
-    
-    if(fs[x].blocks > 0
-       && strcmp(fs[x].type, "proc")
+     sscanf(line, "%s %s %s", fs[x].dev, fs[x].mpoint, fs[x].type);
+     
+     if(strcmp(fs[x].type, "proc")
 #ifndef STAT_NFS
-       && strcmp(fs[x].type, "nfs")
+	&& strcmp(fs[x].type, "nfs")
 #endif
 #ifndef STAT_SMBFS
-       && strcmp(fs[x].type, "smbfs")
+	&& strcmp(fs[x].type, "smbfs")
 #endif
-       ) 
-    {
+	) 
+     {
 #ifdef LINUX
-      y = statfs(fs[x].mpoint, &fsinfo); 
+	y = statfs(fs[x].mpoint, &fsinfo); 
 #else
-      y = statfs(fs[x].mpoint, &fsinfo, sizeof(fsinfo), 0); 
+	y = statfs(fs[x].mpoint, &fsinfo, sizeof(fsinfo), 0); 
 #endif
-      fs[x].bsize = fsinfo.f_bsize; 
-      fs[x].blocks = fsinfo.f_blocks;
-      fs[x].bfree = fsinfo.f_bfree; 
-      fs[x].files = fsinfo.f_files;
-      fs[x].ffree = fsinfo.f_ffree; 
-      x++;
-    }
+	fs[x].blocks = fsinfo.f_blocks;
+	if(fs[x].blocks > 0)
+	{
+	   fs[x].bsize = fsinfo.f_bsize; 
+	   fs[x].bfree = fsinfo.f_bfree; 
+	   fs[x].files = fsinfo.f_files;
+	   fs[x].ffree = fsinfo.f_ffree; 
+	   x++;
+	}
+     }
   }
 
   fclose(mtab_fd);
